==> mkdocs-newsletter-0.2.0.tar.gz: mkdocs-newsletter-0.2.0/docs/install.md <==
We've envisioned the plugin with zero configuration as it's quicker to develop
and easier to use. If you'd like to change the default behaviour, please open
[an issue](https://github.com/lyz-code/mkdocs-newsletter/issues/new).

```bash
pip install mkdocs-newsletter
```

To enable this plugin, you need to declare it in your config file `mkdocs.yml`.

```yaml
plugins:
  - git-revision-date-localized:
      type: timeago
  - autolinks
  - section-index
  - mkdocs-newsletter
```

We rely on:

* [git-revision-date-localized](https://github.com/timvink/mkdocs-git-revision-date-localized-plugin)
    to extract the latest modification date for each newsletter for the RSS.
* [mkdocs-autolink-plugin](https://github.com/midnightprioriem/mkdocs-autolinks-plugin)
    to create the links between the articles.
* [mkdocs-section-index](https://github.com/oprypin/mkdocs-section-index/) to
    make the sections clickable.

To create the RSS feeds well we also need the next configuration:

```yaml
site_url: https://substitute.with.your.site.url
markdown_extensions:
  - toc:
      baselevel: 2
```

# MkDocs configuration enhancements

There are some MkDocs tweaks that can make the plugin work better:

* [Add newsletter information in the footer and the
    header](#add-newsletter-information-in-the-footer-and-the-header).
* [Update the site automatically](#update-the-site-automatically).
* [Exclude the newsletters from the
    search](#exclude-the-newsletters-from-the-search).

## Add newsletter information in the footer and the header

It can be useful to let know the readers that you publish the changes through
newsletters and RSS feeds, we can do that in the footer and the header.

This section is assuming you're using the Material theme. It may work on others
but I haven't tested it

### Footer

You can add the RSS icon to the [Social
links](https://squidfunk.github.io/mkdocs-material/setup/setting-up-the-footer/#social-links)
footer section that points to the newsletter landing page with the next snippet:

```yaml
extra:
  social:
    - icon: fontawesome/solid/rss
      link: https://your.site/newsletter/0_newsletter_index/
```

You can select from
[`fontawesome/solid/rss-square`](https://github.com/squidfunk/mkdocs-material/blob/master/material/.icons/fontawesome/solid/rss-square.svg)
or
[`fontawesome/solid/rss`](https://github.com/squidfunk/mkdocs-material/blob/master/material/.icons/fontawesome/solid/rss.svg).

### Header

You can add an [announce
banner](https://squidfunk.github.io/mkdocs-material/setup/setting-up-the-header/#announcement-bar)
at the top telling your readers to subscribe to the RSS feed by [extending the
theme](https://squidfunk.github.io/mkdocs-material/customization/#extending-the-theme)
and [overriding the `announce`
block](https://squidfunk.github.io/mkdocs-material/customization/#overriding-blocks)
with something like:

Assuming that the override theme directory is `theme`:

!!! note "File: `mkdocs.yml`"
    ```yaml
    theme:
      name: material
      custom_dir: theme
    ```

!!! note "File: `theme/main.html`"

    ```jinja2
    {% extends "base.html" %}

    {% block announce %}
    <a href="https://your.site/newsletter/0_newsletter_index">
        For updates subscribe to the  <strong>RSS feed</strong>
        <span class="rss icon">
        {% include ".icons/fontawesome/solid/rss.svg" %}
        </span>
    </a>
    {% endblock %}
    ```

## Update the site automatically

It's useful to create a continuous integration pipeline to keep the site updated
and automatically build the newsletters.

If you're using github, you can use the next configuration:

??? note "File: `.github/workflows/update.yml`"
    ```yaml
    ---
    name: github pages

    on:
    push:
        branches:
        - master
    schedule:
        - cron: 11 08 * * *

    jobs:
    deploy:
        runs-on: ubuntu-latest
        steps:
        - uses: actions/checkout@v2
            with:
            persist-credentials: false
            # Number of commits to fetch. 0 indicates all history.
            # Default: 1
            fetch-depth: 0

        - name: Setup Python
            # https://github.com/actions/virtual-environments/issues/1202
            # uses: actions/setup-python@v1
            # with:
            #   python-version: '3.7'
            uses: actions/setup-python@v2
            with:
            python-version: 3.7.7
            architecture: x64

        - name: Cache dependencies
            uses: actions/cache@v1
            with:
            path: ~/.cache/pip
            key: ${{ runner.os }}-pip-${{ hashFiles('**/requirements.txt') }}
            restore-keys: |
                ${{ runner.os }}-pip-

        - name: Install dependencies
            run: pip install pip-tools

        - name: Update requirements
            run: make update

        - name: Make the site
            run: make build-docs

        - name: Commit files
            run: |
            git config --local user.email "action@github.com"
            git config --local user.name "GitHub Action"
            git add requirements.txt
            git add docs/newsletter
            git diff-index --quiet HEAD \
                || git commit -m "chore: update dependency and publish newsletters"

        - name: Push changes
            uses: ad-m/github-push-action@master
            with:
            github_token: ${{ secrets.GITHUB_TOKEN }}
            branch: master

        - name: Deploy
            uses: peaceiris/actions-gh-pages@v3
            with:
            deploy_key: ${{ secrets.ACTIONS_DEPLOY_KEY }}
            publish_dir: ./site
    ```

It assumes that you have the next `Makefile`:

??? note "File: `Makefile`"
    ```makefile
    .PHONY: update
    update:
        @echo "-------------------------"
        @echo "- Updating dependencies -"
        @echo "-------------------------"

        rm requirements.txt
        touch requirements.txt
        pip-compile -Ur requirements.in --allow-unsafe

        pip install -r requirements.txt

        @echo ""

    .PHONY: build-docs
    build-docs:
        @echo "--------------------------"
        @echo "- Building documentation -"
        @echo "--------------------------"

        mkdocs build

        @echo ""
    ```

## Exclude the newsletters from the search

If you don't want to see the newsletters in the result of the search, use the
[mkdocs-exclude-search](https://pypi.org/project/mkdocs-exclude-search/) plugin
to exclude all articles under `docs/newsletter`.

==> mkdocs-newsletter-0.3.1.tar.gz: mkdocs-newsletter-0.3.1/docs/install.md <==
We've envisioned the plugin with zero configuration as it's quicker to develop
and easier to use. If you'd like to change the default behaviour, please open
[an issue](https://github.com/lyz-code/mkdocs-newsletter/issues/new).

```bash
pip install mkdocs-newsletter
```

To enable this plugin, you need to declare it in your config file `mkdocs.yml`.

```yaml
plugins:
  - git-revision-date-localized:
      type: timeago
  - autolinks
  - section-index
  - mkdocs-newsletter
```

We rely on:

* [git-revision-date-localized](https://github.com/timvink/mkdocs-git-revision-date-localized-plugin)
    to extract the latest modification date for each newsletter for the RSS.
* [mkdocs-autolink-plugin](https://github.com/midnightprioriem/mkdocs-autolinks-plugin)
    to create the links between the articles.
* [mkdocs-section-index](https://github.com/oprypin/mkdocs-section-index/) to
    make the sections clickable.

To create the RSS feeds well we also need the next configuration:

```yaml
site_url: https://substitute.with.your.site.url
markdown_extensions:
  - toc:
      baselevel: 2
```

# MkDocs configuration enhancements

There are some MkDocs tweaks that can make the plugin work better:

* [Add newsletter information in the footer and the
    header](#add-newsletter-information-in-the-footer-and-the-header).
* [Update the site automatically](#update-the-site-automatically).
* [Exclude the newsletters from the
    search](#exclude-the-newsletters-from-the-search).

## Add newsletter information in the footer and the header

It can be useful to let know the readers that you publish the changes through
newsletters and RSS feeds, we can do that in the footer and the header.

This section is assuming you're using the Material theme. It may work on others
but I haven't tested it

### Footer

You can add the RSS icon to the [Social
links](https://squidfunk.github.io/mkdocs-material/setup/setting-up-the-footer/#social-links)
footer section that points to the newsletter landing page with the next snippet:

```yaml
extra:
  social:
    - icon: fontawesome/solid/rss
      link: https://your.site/newsletter/0_newsletter_index/
```

You can select from
[`fontawesome/solid/rss-square`](https://github.com/squidfunk/mkdocs-material/blob/master/material/.icons/fontawesome/solid/rss-square.svg)
or
[`fontawesome/solid/rss`](https://github.com/squidfunk/mkdocs-material/blob/master/material/.icons/fontawesome/solid/rss.svg).

### Header

You can add an [announce
banner](https://squidfunk.github.io/mkdocs-material/setup/setting-up-the-header/#announcement-bar)
at the top telling your readers to subscribe to the RSS feed by [extending the
theme](https://squidfunk.github.io/mkdocs-material/customization/#extending-the-theme)
and [overriding the `announce`
block](https://squidfunk.github.io/mkdocs-material/customization/#overriding-blocks)
with something like:

Assuming that the override theme directory is `theme`:

!!! note "File: `mkdocs.yml`"
    ```yaml
    theme:
      name: material
      custom_dir: theme
    ```

!!! note "File: `theme/main.html`"

    ```jinja2
    {% extends "base.html" %}

    {% block announce %}
    <a href="https://your.site/newsletter/0_newsletter_index">
        For updates subscribe to the  <strong>RSS feed</strong>
        <span class="rss icon">
        {% include ".icons/fontawesome/solid/rss.svg" %}
        </span>
    </a>
    {% endblock %}
    ```

## Update the site automatically

It's useful to create a continuous integration pipeline to keep the site updated
and automatically build the newsletters.

If you're using github, you can use the next configuration:

??? note "File: `.github/workflows/update.yml`"
    ```yaml
    ---
    name: github pages

    on:
    push:
        branches:
        - master
    schedule:
        - cron: 11 08 * * *

    jobs:
    deploy:
        runs-on: ubuntu-latest
        steps:
        - uses: actions/checkout@v2
            with:
            persist-credentials: false
            # Number of commits to fetch. 0 indicates all history.
            # Default: 1
            fetch-depth: 0

        - name: Setup Python
            # https://github.com/actions/virtual-environments/issues/1202
            # uses: actions/setup-python@v1
            # with:
            #   python-version: '3.7'
            uses: actions/setup-python@v2
            with:
            python-version: 3.7.7
            architecture: x64

        - name: Cache dependencies
            uses: actions/cache@v1
            with:
            path: ~/.cache/pip
            key: ${{ runner.os }}-pip-${{ hashFiles('**/requirements.txt') }}
            restore-keys: |
                ${{ runner.os }}-pip-

        - name: Install dependencies
            run: pip install pip-tools

        - name: Update requirements
            run: make update

        - name: Make the site
            run: make build-docs

        - name: Commit files
            run: |
            git config --local user.email "action@github.com"
            git config --local user.name "GitHub Action"
            git add requirements.txt
            git add docs/newsletter
            git diff-index --quiet HEAD \
                || git commit -m "chore: update dependency and publish newsletters"

        - name: Push changes
            uses: ad-m/github-push-action@master
            with:
            github_token: ${{ secrets.GITHUB_TOKEN }}
            branch: master

        - name: Deploy
            uses: peaceiris/actions-gh-pages@v3
            with:
            deploy_key: ${{ secrets.ACTIONS_DEPLOY_KEY }}
            publish_dir: ./site
    ```

It assumes that you have the next `Makefile`:

??? note "File: `Makefile`"
    ```makefile
    .PHONY: update
    update:
        @echo "-------------------------"
        @echo "- Updating dependencies -"
        @echo "-------------------------"

        rm requirements.txt
        touch requirements.txt
        pip-compile -Ur requirements.in --allow-unsafe

        pip install -r requirements.txt

        @echo ""

    .PHONY: build-docs
    build-docs:
        @echo "--------------------------"
        @echo "- Building documentation -"
        @echo "--------------------------"

        mkdocs build

        @echo ""
    ```

## Exclude the newsletters from the search

If you don't want to see the newsletters in the result of the search, use the
[mkdocs-exclude-search](https://pypi.org/project/mkdocs-exclude-search/) plugin
to exclude all articles under `newsletter/`.

To do so:

1. Install the plugin with
   ```bash
   pip install mkdocs-exclude-search
   ```
1. Add the following configuration to your `mkdocs.yml`
   ```yaml
   plugins:
     - search
     - exclude-search:
         exclude:
           - newsletter/*
   ```
   
Note that `newsletter/*` excludes all markdown files within a directory and its children. The paths must be relative to the `docs/` directory.
